import java.net.*;
import java.io.*;

import java.rmi.*;
import java.rmi.server.*;
import java.rmi.registry.LocateRegistry;

/**
* RMIServer01 acts as a server for the remote "TimerServer" object.
*
* RMIServer01 relies on RMIServer to do command line processing.
*/

public class RMIServer01 extends RMIServer
{
   private static final int    PORT        = 11002;
   private static final String DATE        = "10-July-1997";
   private static final String NAME        = "RMIServer01";
   private static final String DESCRIPTION = "RMIServer for TimeService";
   private static final int    MAJOR       = 1;
   private static final int    MINOR       = 0;
   
   // Instance of ourselves
   private static RMIServer  rmi;
   
   // Instance of the Root Object(s)
   private static TimeServer      ts;
   
   public static void main ( String[] args )
   {
      System.setSecurityManager( new RMISecurityManager() );
      
      try
      {
         rmi = new RMIServer01( args );
      }
      catch ( RemoteException re )
      {
         System.out.println( "Error starting service" );
         System.out.println( "" + re );
      }
      catch ( MalformedURLException mURLe )
      {
         System.out.println( "Internal error" + mURLe );
      }
      
   }  // main
   
   
   // Constructor
   public RMIServer01( String[] args ) throws RemoteException, MalformedURLException
   {
      // Super Class does the command line processing for us!
      super( args, PORT, DATE, NAME, DESCRIPTION, MAJOR, MINOR );
      
      LocateRegistry.createRegistry( PORT );
      
      System.out.println( "Registry created" );
      
      ts = new TimeServerImpl();
      
      Naming.rebind( "//" + hostName + ":" + registryPort + "/" + "TimeService", ts );
      
      System.out.println( "Bindings Finished" );
   }
   
}  // class RMIServer01
