import java.net.*;
import java.io.*;

import java.rmi.*;
import java.rmi.server.*;
import java.rmi.registry.LocateRegistry;

/**
 * RMIServer02 acts as a server for the remote "ChatService" system.
 *
 * RMIServer02 relies on RMIServer to do command line processing.
 */

public class RMIServer02 extends RMIServer
{
   private static final int    PORT        = 10002;
   private static final String DATE        = "05-August-1997";
   private static final String NAME        = "RMIServer02";
   private static final String DESCRIPTION = "RMIServer for ChatService";
   private static final int    MAJOR       = 1;
   private static final int    MINOR       = 0;

   // Instance of ourselves
   private static RMIServer  rmi;

   // Instance of the Root Object(s)
   private static ChatManager cm;

   public static void main ( String[] args )
   {
      System.setSecurityManager( new RMISecurityManager() );

      try
      {
         rmi = new RMIServer02( args );
      }
      catch ( RemoteException re )
      {
         System.out.println( "Error starting service" );
         System.out.println( "" + re );
      }
      catch ( MalformedURLException mURLe )
      {
         System.out.println( "Internal error" + mURLe );
      }

   }  // main


   // Constructor
   public RMIServer02( String[] args ) throws RemoteException, MalformedURLException
   {
      // Super Class does the command line processing for us!
      super( args, PORT, DATE, NAME, DESCRIPTION, MAJOR, MINOR );

      LocateRegistry.createRegistry( PORT );

      System.out.println( "Registry created" );

      cm = new ChatManagerImpl();

      Naming.rebind( "//" + hostName + ":" + registryPort + "/" + "ChatService", cm );

      System.out.println( "Bindings Finished" );
   }

}  // class RMIServer02
